from dataflow.utils.registry import OPERATOR_REGISTRY
from inspect import signature
from pprint import pprint

# 全局table，看所有注册的算子的str名称和对应的module路径
print(OPERATOR_REGISTRY)

# 获得所有算子的类名2class映射
dataflow_obj_map = OPERATOR_REGISTRY.get_obj_map()

print(dataflow_obj_map)

# 遍历所有算子，打印其名称和对象，以及init函数和run函数的签名，以及形参列表
for name, obj in dataflow_obj_map.items():
    # use Blue color for the name
    print(f"\033[94mName: {name}, Object {obj}\033[0m")
    # get signature of the run and __init__ methods for each operator
    if hasattr(obj, 'run'):
        run_signature = signature(obj.run)
        run_signature_params = run_signature.parameters
        # green color for run method
        print("\033[92m  run signature: \033[0m")
        pprint(run_signature)
        print("\033[92m  run signature parameters: \033[0m")
        pprint(run_signature_params)
    if hasattr(obj, '__init__'):
        init_signature = signature(obj.__init__)
        init_signature_params = init_signature.parameters
        # green color for __init__ method
        print("\033[92m  __init__ signature: \033[0m")
        pprint(init_signature)
        print("\033[92m  __init__ signature parameters: \033[0m")
        pprint(init_signature_params)
    print()